package checksum

import (
	"hash"
	"hash/crc32"
	"hash/crc64"
)

var (
	IEEETable       = crc32.IEEETable
	CastagnoliTable = crc32.MakeTable(crc32.Castagnoli)
	KoopmanTable    = crc32.MakeTable(crc32.Koopman)

	ISOTable  = crc64.MakeTable(crc64.ISO)
	ECMATable = crc64.MakeTable(crc64.ECMA)
)

type (
	Crc32Ieee struct {
		d hash.Hash
	}
	Crc32Castagnoli struct {
		d hash.Hash
	}
	Crc32Koopman struct {
		d hash.Hash
	}
	Crc64Iso struct {
		d hash.Hash
	}
	Crc64Ecma struct {
		d hash.Hash
	}
)

func (m *Crc32Ieee) String() string {
	return "crc32ieee"
}

func (m *Crc32Ieee) Append(data []byte) {
	if m.d == nil {
		m.d = crc32.New(IEEETable)
	}

	m.d.Write(data)
}

func (m *Crc32Ieee) Finish() []byte {
	if m.d == nil {
		m.d = crc32.New(IEEETable)
	}

	return m.d.Sum(nil)
}

func (m *Crc32Castagnoli) String() string {
	return "crc32castagnoli"
}

func (m *Crc32Castagnoli) Append(data []byte) {
	if m.d == nil {
		m.d = crc32.New(CastagnoliTable)
	}

	m.d.Write(data)
}

func (m *Crc32Castagnoli) Finish() []byte {
	if m.d == nil {
		m.d = crc32.New(CastagnoliTable)
	}

	return m.d.Sum(nil)
}

func (m *Crc32Koopman) String() string {
	return "crc32koopman"
}

func (m *Crc32Koopman) Append(data []byte) {
	if m.d == nil {
		m.d = crc32.New(KoopmanTable)
	}

	m.d.Write(data)
}

func (m *Crc32Koopman) Finish() []byte {
	if m.d == nil {
		m.d = crc32.New(KoopmanTable)
	}

	return m.d.Sum(nil)
}

func (m *Crc64Iso) String() string {
	return "crc64iso"
}

func (m *Crc64Iso) Append(data []byte) {
	if m.d == nil {
		m.d = crc64.New(ISOTable)
	}

	m.d.Write(data)
}

func (m *Crc64Iso) Finish() []byte {
	if m.d == nil {
		m.d = crc64.New(ISOTable)
	}

	return m.d.Sum(nil)
}

func (m *Crc64Ecma) String() string {
	return "crc64ecma"
}

func (m *Crc64Ecma) Append(data []byte) {
	if m.d == nil {
		m.d = crc64.New(ECMATable)
	}

	m.d.Write(data)
}

func (m *Crc64Ecma) Finish() []byte {
	if m.d == nil {
		m.d = crc64.New(ECMATable)
	}

	return m.d.Sum(nil)
}
