package checksum

import (
	"github.com/tursom/checksum/assert"
	"hash"
	"hash/fnv"
	"testing"
)

func TestFnv64_Finish(t *testing.T) {
	type fields struct {
		d hash.Hash
	}
	tests := []struct {
		name    string
		fields  fields
		builder func(m *Fnv64)
		want    []byte
	}{
		{
			"nil",
			fields{},
			nil,
			fnv.New64().Sum(nil),
		},
		{
			"hello",
			fields{},
			func(m *Fnv64) {
				m.Append([]byte("hello"))
			},
			fnv64Sum([]byte("hello")),
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			m := &Fnv64{
				d: tt.fields.d,
			}
			if tt.builder != nil {
				tt.builder(m)
			}

			assert.Equals(t, m.Finish(), tt.want)
		})
	}
}

func fnv64Sum(b []byte) []byte {
	h := fnv.New64()
	_, _ = h.Write(b)
	return h.Sum(nil)
}

func TestFnv64_String(t *testing.T) {
	assert.Equals(t, (&Fnv64{}).String(), "fnv64")
}
