package checksum

import (
	"github.com/spaolacci/murmur3"
	"github.com/tursom/checksum/assert"
	"hash"
	"testing"
)

func TestMurmur3128_Finish(t *testing.T) {
	type fields struct {
		d hash.Hash
	}
	tests := []struct {
		name    string
		fields  fields
		builder func(m *Murmur3128)
		want    []byte
	}{
		{
			"nil",
			fields{},
			nil,
			murmur3.New128().Sum(nil),
		},
		{
			"hello",
			fields{},
			func(m *Murmur3128) {
				m.Append([]byte("hello"))
			},
			murmur3128Sum([]byte("hello")),
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			m := &Murmur3128{
				d: tt.fields.d,
			}
			if tt.builder != nil {
				tt.builder(m)
			}

			assert.Equals(t, m.Finish(), tt.want)
		})
	}
}

func murmur3128Sum(b []byte) []byte {
	h := murmur3.New128()
	_, _ = h.Write(b)
	return h.Sum(nil)
}

func TestMurmur3128_String(t *testing.T) {
	assert.Equals(t, (&Murmur3128{}).String(), "murmur3 128")
}
