package checksum

import (
	"crypto/sha512"
	"github.com/tursom/checksum/assert"
	"hash"
	"testing"
)

func TestSha512_Finish(t *testing.T) {
	type fields struct {
		d hash.Hash
	}
	tests := []struct {
		name    string
		fields  fields
		builder func(m *Sha512)
		want    []byte
	}{
		{
			"nil",
			fields{},
			nil,
			sha512.New().Sum(nil),
		},
		{
			"hello",
			fields{},
			func(m *Sha512) {
				m.Append([]byte("hello"))
			},
			sha512Sum([]byte("hello")),
		},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			m := &Sha512{
				d: tt.fields.d,
			}
			if tt.builder != nil {
				tt.builder(m)
			}

			assert.Equals(t, m.Finish(), tt.want)
		})
	}
}

func sha512Sum(b []byte) []byte {
	h := sha512.New()
	_, _ = h.Write(b)
	return h.Sum(nil)
}

func TestSha512_String(t *testing.T) {
	assert.Equals(t, (&Sha512{}).String(), "sha512")
}
